proto

package
v0.0.0-...-262290f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 30, 2025 License: Apache-2.0 Imports: 10 Imported by: 1

Documentation

Index

Constants

const (
	BackupService_Backup_FullMethodName  = "/backup.BackupService/Backup"
	BackupService_Update_FullMethodName  = "/backup.BackupService/Update"
	BackupService_Restore_FullMethodName = "/backup.BackupService/Restore"
)
const (
	BackupMetricsService_ReportSuccessfulBackup_FullMethodName = "/backupmetrics.BackupMetricsService/ReportSuccessfulBackup"
	BackupMetricsService_ReportRestoreStatus_FullMethodName    = "/backupmetrics.BackupMetricsService/ReportRestoreStatus"
)

Variables

var BackupMetricsService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "backupmetrics.BackupMetricsService",
	HandlerType: (*BackupMetricsServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "ReportSuccessfulBackup",
			Handler:    _BackupMetricsService_ReportSuccessfulBackup_Handler,
		},
		{
			MethodName: "ReportRestoreStatus",
			Handler:    _BackupMetricsService_ReportRestoreStatus_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/metrics.proto",
}

BackupMetricsService_ServiceDesc is the grpc.ServiceDesc for BackupMetricsService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var BackupService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "backup.BackupService",
	HandlerType: (*BackupServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Backup",
			Handler:    _BackupService_Backup_Handler,
		},
		{
			MethodName: "Update",
			Handler:    _BackupService_Update_Handler,
		},
		{
			MethodName: "Restore",
			Handler:    _BackupService_Restore_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/backup.proto",
}

BackupService_ServiceDesc is the grpc.ServiceDesc for BackupService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_proto_backup_proto protoreflect.FileDescriptor
var File_proto_metrics_proto protoreflect.FileDescriptor

Functions

func RegisterBackupMetricsServiceServer

func RegisterBackupMetricsServiceServer(s grpc.ServiceRegistrar, srv BackupMetricsServiceServer)

func RegisterBackupServiceServer

func RegisterBackupServiceServer(s grpc.ServiceRegistrar, srv BackupServiceServer)

Types

type BackupMetrics

type BackupMetrics struct {
	BackupName  string `protobuf:"bytes,1,opt,name=backup_name,json=backupName,proto3" json:"backup_name,omitempty"`
	Success     bool   `protobuf:"varint,2,opt,name=success,proto3" json:"success,omitempty"`
	TimeElapsed int64  `protobuf:"varint,3,opt,name=time_elapsed,json=timeElapsed,proto3" json:"time_elapsed,omitempty"`
	// contains filtered or unexported fields
}

func (*BackupMetrics) Descriptor deprecated

func (*BackupMetrics) Descriptor() ([]byte, []int)

Deprecated: Use BackupMetrics.ProtoReflect.Descriptor instead.

func (*BackupMetrics) GetBackupName

func (x *BackupMetrics) GetBackupName() string

func (*BackupMetrics) GetSuccess

func (x *BackupMetrics) GetSuccess() bool

func (*BackupMetrics) GetTimeElapsed

func (x *BackupMetrics) GetTimeElapsed() int64

func (*BackupMetrics) ProtoMessage

func (*BackupMetrics) ProtoMessage()

func (*BackupMetrics) ProtoReflect

func (x *BackupMetrics) ProtoReflect() protoreflect.Message

func (*BackupMetrics) Reset

func (x *BackupMetrics) Reset()

func (*BackupMetrics) String

func (x *BackupMetrics) String() string

type BackupMetricsServiceClient

type BackupMetricsServiceClient interface {
	ReportSuccessfulBackup(ctx context.Context, in *BackupMetrics, opts ...grpc.CallOption) (*empty.Empty, error)
	ReportRestoreStatus(ctx context.Context, in *RestoreMetrics, opts ...grpc.CallOption) (*empty.Empty, error)
}

BackupMetricsServiceClient is the client API for BackupMetricsService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type BackupMetricsServiceServer

type BackupMetricsServiceServer interface {
	ReportSuccessfulBackup(context.Context, *BackupMetrics) (*empty.Empty, error)
	ReportRestoreStatus(context.Context, *RestoreMetrics) (*empty.Empty, error)
	// contains filtered or unexported methods
}

BackupMetricsServiceServer is the server API for BackupMetricsService service. All implementations must embed UnimplementedBackupMetricsServiceServer for forward compatibility.

type BackupRequest

type BackupRequest struct {
	DbUri          string `protobuf:"bytes,1,opt,name=db_uri,json=dbUri,proto3" json:"db_uri,omitempty"`
	DbPort         int64  `protobuf:"varint,2,opt,name=db_port,json=dbPort,proto3" json:"db_port,omitempty"`
	DbUser         string `protobuf:"bytes,3,opt,name=db_user,json=dbUser,proto3" json:"db_user,omitempty"`
	DbPass         string `protobuf:"bytes,4,opt,name=db_pass,json=dbPass,proto3" json:"db_pass,omitempty"`
	DbName         string `protobuf:"bytes,5,opt,name=db_name,json=dbName,proto3" json:"db_name,omitempty"`
	DatabaseType   string `protobuf:"bytes,6,opt,name=database_type,json=databaseType,proto3" json:"database_type,omitempty"`
	Schedule       string `protobuf:"bytes,7,opt,name=schedule,proto3" json:"schedule,omitempty"`
	S3Endpoint     string `protobuf:"bytes,9,opt,name=s3_endpoint,json=s3Endpoint,proto3" json:"s3_endpoint,omitempty"`
	S3AccessKey    string `protobuf:"bytes,10,opt,name=s3_access_key,json=s3AccessKey,proto3" json:"s3_access_key,omitempty"`
	S3SecretKey    string `protobuf:"bytes,11,opt,name=s3_secret_key,json=s3SecretKey,proto3" json:"s3_secret_key,omitempty"`
	S3BucketName   string `protobuf:"bytes,12,opt,name=s3_bucket_name,json=s3BucketName,proto3" json:"s3_bucket_name,omitempty"`
	CoreAddr       string `protobuf:"bytes,13,opt,name=core_addr,json=coreAddr,proto3" json:"core_addr,omitempty"`
	MaxBackupCount int64  `protobuf:"varint,14,opt,name=max_backup_count,json=maxBackupCount,proto3" json:"max_backup_count,omitempty"`
	// contains filtered or unexported fields
}

func (*BackupRequest) Descriptor deprecated

func (*BackupRequest) Descriptor() ([]byte, []int)

Deprecated: Use BackupRequest.ProtoReflect.Descriptor instead.

func (*BackupRequest) GetCoreAddr

func (x *BackupRequest) GetCoreAddr() string

func (*BackupRequest) GetDatabaseType

func (x *BackupRequest) GetDatabaseType() string

func (*BackupRequest) GetDbName

func (x *BackupRequest) GetDbName() string

func (*BackupRequest) GetDbPass

func (x *BackupRequest) GetDbPass() string

func (*BackupRequest) GetDbPort

func (x *BackupRequest) GetDbPort() int64

func (*BackupRequest) GetDbUri

func (x *BackupRequest) GetDbUri() string

func (*BackupRequest) GetDbUser

func (x *BackupRequest) GetDbUser() string

func (*BackupRequest) GetMaxBackupCount

func (x *BackupRequest) GetMaxBackupCount() int64

func (*BackupRequest) GetS3AccessKey

func (x *BackupRequest) GetS3AccessKey() string

func (*BackupRequest) GetS3BucketName

func (x *BackupRequest) GetS3BucketName() string

func (*BackupRequest) GetS3Endpoint

func (x *BackupRequest) GetS3Endpoint() string

func (*BackupRequest) GetS3SecretKey

func (x *BackupRequest) GetS3SecretKey() string

func (*BackupRequest) GetSchedule

func (x *BackupRequest) GetSchedule() string

func (*BackupRequest) ProtoMessage

func (*BackupRequest) ProtoMessage()

func (*BackupRequest) ProtoReflect

func (x *BackupRequest) ProtoReflect() protoreflect.Message

func (*BackupRequest) Reset

func (x *BackupRequest) Reset()

func (*BackupRequest) String

func (x *BackupRequest) String() string

type BackupResponse

type BackupResponse struct {
	Status           string `protobuf:"bytes,1,opt,name=status,proto3" json:"status,omitempty"`
	CronjobName      string `protobuf:"bytes,2,opt,name=cronjob_name,json=cronjobName,proto3" json:"cronjob_name,omitempty"`
	CronjobNamespace string `protobuf:"bytes,3,opt,name=cronjob_namespace,json=cronjobNamespace,proto3" json:"cronjob_namespace,omitempty"`
	// contains filtered or unexported fields
}

func (*BackupResponse) Descriptor deprecated

func (*BackupResponse) Descriptor() ([]byte, []int)

Deprecated: Use BackupResponse.ProtoReflect.Descriptor instead.

func (*BackupResponse) GetCronjobName

func (x *BackupResponse) GetCronjobName() string

func (*BackupResponse) GetCronjobNamespace

func (x *BackupResponse) GetCronjobNamespace() string

func (*BackupResponse) GetStatus

func (x *BackupResponse) GetStatus() string

func (*BackupResponse) ProtoMessage

func (*BackupResponse) ProtoMessage()

func (*BackupResponse) ProtoReflect

func (x *BackupResponse) ProtoReflect() protoreflect.Message

func (*BackupResponse) Reset

func (x *BackupResponse) Reset()

func (*BackupResponse) String

func (x *BackupResponse) String() string

type BackupRestore

type BackupRestore struct {
	DbUri          string `protobuf:"bytes,1,opt,name=db_uri,json=dbUri,proto3" json:"db_uri,omitempty"`
	DbPort         int64  `protobuf:"varint,2,opt,name=db_port,json=dbPort,proto3" json:"db_port,omitempty"`
	DbUser         string `protobuf:"bytes,3,opt,name=db_user,json=dbUser,proto3" json:"db_user,omitempty"`
	DbPass         string `protobuf:"bytes,4,opt,name=db_pass,json=dbPass,proto3" json:"db_pass,omitempty"`
	DbName         string `protobuf:"bytes,5,opt,name=db_name,json=dbName,proto3" json:"db_name,omitempty"`
	DatabaseType   string `protobuf:"bytes,6,opt,name=database_type,json=databaseType,proto3" json:"database_type,omitempty"`
	S3Endpoint     string `protobuf:"bytes,9,opt,name=s3_endpoint,json=s3Endpoint,proto3" json:"s3_endpoint,omitempty"`
	S3AccessKey    string `protobuf:"bytes,10,opt,name=s3_access_key,json=s3AccessKey,proto3" json:"s3_access_key,omitempty"`
	S3SecretKey    string `protobuf:"bytes,11,opt,name=s3_secret_key,json=s3SecretKey,proto3" json:"s3_secret_key,omitempty"`
	S3BucketName   string `protobuf:"bytes,12,opt,name=s3_bucket_name,json=s3BucketName,proto3" json:"s3_bucket_name,omitempty"`
	BackupRevision string `protobuf:"bytes,13,opt,name=backupRevision,proto3" json:"backupRevision,omitempty"`
	CoreAddr       string `protobuf:"bytes,14,opt,name=core_addr,json=coreAddr,proto3" json:"core_addr,omitempty"`
	// contains filtered or unexported fields
}

func (*BackupRestore) Descriptor deprecated

func (*BackupRestore) Descriptor() ([]byte, []int)

Deprecated: Use BackupRestore.ProtoReflect.Descriptor instead.

func (*BackupRestore) GetBackupRevision

func (x *BackupRestore) GetBackupRevision() string

func (*BackupRestore) GetCoreAddr

func (x *BackupRestore) GetCoreAddr() string

func (*BackupRestore) GetDatabaseType

func (x *BackupRestore) GetDatabaseType() string

func (*BackupRestore) GetDbName

func (x *BackupRestore) GetDbName() string

func (*BackupRestore) GetDbPass

func (x *BackupRestore) GetDbPass() string

func (*BackupRestore) GetDbPort

func (x *BackupRestore) GetDbPort() int64

func (*BackupRestore) GetDbUri

func (x *BackupRestore) GetDbUri() string

func (*BackupRestore) GetDbUser

func (x *BackupRestore) GetDbUser() string

func (*BackupRestore) GetS3AccessKey

func (x *BackupRestore) GetS3AccessKey() string

func (*BackupRestore) GetS3BucketName

func (x *BackupRestore) GetS3BucketName() string

func (*BackupRestore) GetS3Endpoint

func (x *BackupRestore) GetS3Endpoint() string

func (*BackupRestore) GetS3SecretKey

func (x *BackupRestore) GetS3SecretKey() string

func (*BackupRestore) ProtoMessage

func (*BackupRestore) ProtoMessage()

func (*BackupRestore) ProtoReflect

func (x *BackupRestore) ProtoReflect() protoreflect.Message

func (*BackupRestore) Reset

func (x *BackupRestore) Reset()

func (*BackupRestore) String

func (x *BackupRestore) String() string

type BackupRestoreResponse

type BackupRestoreResponse struct {
	Status       string `protobuf:"bytes,1,opt,name=status,proto3" json:"status,omitempty"`
	JobName      string `protobuf:"bytes,2,opt,name=job_name,json=jobName,proto3" json:"job_name,omitempty"`
	JobNamespace string `protobuf:"bytes,3,opt,name=job_namespace,json=jobNamespace,proto3" json:"job_namespace,omitempty"`
	// contains filtered or unexported fields
}

func (*BackupRestoreResponse) Descriptor deprecated

func (*BackupRestoreResponse) Descriptor() ([]byte, []int)

Deprecated: Use BackupRestoreResponse.ProtoReflect.Descriptor instead.

func (*BackupRestoreResponse) GetJobName

func (x *BackupRestoreResponse) GetJobName() string

func (*BackupRestoreResponse) GetJobNamespace

func (x *BackupRestoreResponse) GetJobNamespace() string

func (*BackupRestoreResponse) GetStatus

func (x *BackupRestoreResponse) GetStatus() string

func (*BackupRestoreResponse) ProtoMessage

func (*BackupRestoreResponse) ProtoMessage()

func (*BackupRestoreResponse) ProtoReflect

func (x *BackupRestoreResponse) ProtoReflect() protoreflect.Message

func (*BackupRestoreResponse) Reset

func (x *BackupRestoreResponse) Reset()

func (*BackupRestoreResponse) String

func (x *BackupRestoreResponse) String() string

type BackupServiceClient

type BackupServiceClient interface {
	Backup(ctx context.Context, in *BackupRequest, opts ...grpc.CallOption) (*BackupResponse, error)
	Update(ctx context.Context, in *UpdateBackupRequest, opts ...grpc.CallOption) (*BackupResponse, error)
	Restore(ctx context.Context, in *BackupRestore, opts ...grpc.CallOption) (*BackupRestoreResponse, error)
}

BackupServiceClient is the client API for BackupService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type BackupServiceServer

type BackupServiceServer interface {
	Backup(context.Context, *BackupRequest) (*BackupResponse, error)
	Update(context.Context, *UpdateBackupRequest) (*BackupResponse, error)
	Restore(context.Context, *BackupRestore) (*BackupRestoreResponse, error)
	// contains filtered or unexported methods
}

BackupServiceServer is the server API for BackupService service. All implementations must embed UnimplementedBackupServiceServer for forward compatibility.

type RestoreMetrics

type RestoreMetrics struct {
	RestoreName string `protobuf:"bytes,1,opt,name=restore_name,json=restoreName,proto3" json:"restore_name,omitempty"`
	Success     bool   `protobuf:"varint,2,opt,name=success,proto3" json:"success,omitempty"`
	TimeElapsed int64  `protobuf:"varint,3,opt,name=time_elapsed,json=timeElapsed,proto3" json:"time_elapsed,omitempty"`
	// contains filtered or unexported fields
}

func (*RestoreMetrics) Descriptor deprecated

func (*RestoreMetrics) Descriptor() ([]byte, []int)

Deprecated: Use RestoreMetrics.ProtoReflect.Descriptor instead.

func (*RestoreMetrics) GetRestoreName

func (x *RestoreMetrics) GetRestoreName() string

func (*RestoreMetrics) GetSuccess

func (x *RestoreMetrics) GetSuccess() bool

func (*RestoreMetrics) GetTimeElapsed

func (x *RestoreMetrics) GetTimeElapsed() int64

func (*RestoreMetrics) ProtoMessage

func (*RestoreMetrics) ProtoMessage()

func (*RestoreMetrics) ProtoReflect

func (x *RestoreMetrics) ProtoReflect() protoreflect.Message

func (*RestoreMetrics) Reset

func (x *RestoreMetrics) Reset()

func (*RestoreMetrics) String

func (x *RestoreMetrics) String() string

type UnimplementedBackupMetricsServiceServer

type UnimplementedBackupMetricsServiceServer struct{}

UnimplementedBackupMetricsServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedBackupMetricsServiceServer) ReportRestoreStatus

func (UnimplementedBackupMetricsServiceServer) ReportSuccessfulBackup

type UnimplementedBackupServiceServer

type UnimplementedBackupServiceServer struct{}

UnimplementedBackupServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedBackupServiceServer) Backup

func (UnimplementedBackupServiceServer) Restore

func (UnimplementedBackupServiceServer) Update

type UnsafeBackupMetricsServiceServer

type UnsafeBackupMetricsServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeBackupMetricsServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to BackupMetricsServiceServer will result in compilation errors.

type UnsafeBackupServiceServer

type UnsafeBackupServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeBackupServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to BackupServiceServer will result in compilation errors.

type UpdateBackupRequest

type UpdateBackupRequest struct {
	Request          *BackupRequest `protobuf:"bytes,1,opt,name=request,proto3" json:"request,omitempty"`
	CronjobName      string         `protobuf:"bytes,2,opt,name=cronjob_name,json=cronjobName,proto3" json:"cronjob_name,omitempty"`
	CronjobNamespace string         `protobuf:"bytes,3,opt,name=cronjob_namespace,json=cronjobNamespace,proto3" json:"cronjob_namespace,omitempty"`
	// contains filtered or unexported fields
}

func (*UpdateBackupRequest) Descriptor deprecated

func (*UpdateBackupRequest) Descriptor() ([]byte, []int)

Deprecated: Use UpdateBackupRequest.ProtoReflect.Descriptor instead.

func (*UpdateBackupRequest) GetCronjobName

func (x *UpdateBackupRequest) GetCronjobName() string

func (*UpdateBackupRequest) GetCronjobNamespace

func (x *UpdateBackupRequest) GetCronjobNamespace() string

func (*UpdateBackupRequest) GetRequest

func (x *UpdateBackupRequest) GetRequest() *BackupRequest

func (*UpdateBackupRequest) ProtoMessage

func (*UpdateBackupRequest) ProtoMessage()

func (*UpdateBackupRequest) ProtoReflect

func (x *UpdateBackupRequest) ProtoReflect() protoreflect.Message

func (*UpdateBackupRequest) Reset

func (x *UpdateBackupRequest) Reset()

func (*UpdateBackupRequest) String

func (x *UpdateBackupRequest) String() string

Jump to